summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorRen Kuo <ren.kuo@quanta.corp-partner.google.com>2024-09-25 14:06:33 +0800
committerKarthik Ramasubramanian <kramasub@google.com>2024-10-08 21:55:27 +0000
commite80eea6d45943c3e6f020b3d07e36870af255698 (patch)
tree7bb7e6c9c353a46a2ec395871388206fda2f370a /src
parent9c15a9b7ae2efa35063c5d4c83124381b657e298 (diff)
mb/google/brox/jubilant: Update FP IRQ pin to GPP_D13 in fp_disable_pads
Commit 8cfe1b3302ff (mb/google/brox/jubilant: Modify FP IRQ pin to GPP_D13): CB:84124, changes the fingerprint IRQ pin from GPP_F15 to GPP_D13, but forgot to update the pin in the array fp_disable_pads. Hence update fp_disable_pads configuration to include that GPIO. BUG=None TEST= build firmware $ emerge-brox coreboot Change-Id: Iee4c3d3f000f884ca8a77ae8c72ccbeebfeb865f Signed-off-by: Ren Kuo <ren.kuo@quanta.corp-partner.google.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/84545 Reviewed-by: Karthik Ramasubramanian <kramasub@google.com> Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Kenneth Chan <kenneth.chan@quanta.corp-partner.google.com>
Diffstat (limited to 'src')
-rw-r--r--src/mainboard/google/brox/variants/jubilant/fw_config.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mainboard/google/brox/variants/jubilant/fw_config.c b/src/mainboard/google/brox/variants/jubilant/fw_config.c
index 5076c73613..df57e15804 100644
--- a/src/mainboard/google/brox/variants/jubilant/fw_config.c
+++ b/src/mainboard/google/brox/variants/jubilant/fw_config.c
@@ -13,8 +13,8 @@ static const struct pad_config fp_disable_pads[] = {
PAD_NC(GPP_D3, NONE),
/* GPP_D15 : FPMCU_RST_J_SUB_L (active low) (NC) */
PAD_NC(GPP_D15, NONE),
- /* GPP_F15 : FP GSPI INT (NC) */
- PAD_NC(GPP_F15, NONE),
+ /* GPP_D13 : FP GSPI INT (NC) */
+ PAD_NC(GPP_D13, NONE),
/* GPP_F11 : FP GSPI CLK (NC) */
PAD_NC(GPP_F11, NONE),
/* GPP_F12 : FP GSPI DO (NC) */